@@ -1,12 +1,24 @@
-import asyncio
-
 from .executor import CoroBuilder
-from multiprocessing import (Event, Lock, RLock, BoundedSemaphore,
-                             Condition, Semaphore, Barrier)
+from multiprocessing import (
+    Event,
+    Lock,
+    RLock,
+    BoundedSemaphore,
+    Condition,
+    Semaphore,
+    Barrier,
+)
 from multiprocessing.util import register_after_fork
 
-__all__ = ["AioLock", "AioRLock", "AioBarrier", "AioCondition", "AioEvent",
-           "AioSemaphore", "AioBoundedSemaphore"]
+__all__ = [
+    "AioLock",
+    "AioRLock",
+    "AioBarrier",
+    "AioCondition",
+    "AioEvent",
+    "AioSemaphore",
+    "AioBoundedSemaphore",
+]
 
 
 class _ContextManager:
@@ -15,7 +27,7 @@ class _ContextManager:
     This enables the following idiom for acquiring and releasing a
     lock around a block:
 
-        with (yield from lock):
+        async with lock:
             <block>
 
     """
@@ -37,13 +49,14 @@ class _ContextManager:
 
 class AioBaseLock(metaclass=CoroBuilder):
     pool_workers = 1
-    coroutines = ['acquire', 'release']
+    coroutines = ["acquire", "release"]
 
     def __init__(self, *args, **kwargs):
         self._threaded_acquire = False
 
         def _after_fork(obj):
             obj._threaded_acquire = False
+
         register_after_fork(self, _after_fork)
 
     def coro_acquire(self, *args, **kwargs):
@@ -56,6 +69,7 @@ class AioBaseLock(metaclass=CoroBuilder):
         or in the Executor thread.
 
         """
+
         def lock_acquired(fut):
             if fut.result():
                 self._threaded_acquire = True
@@ -66,7 +80,7 @@ class AioBaseLock(metaclass=CoroBuilder):
 
     def __getstate__(self):
         state = super().__getstate__()
-        state['_threaded_acquire'] = False
+        state["_threaded_acquire"] = False
         return state
 
     def __setstate__(self, state):
@@ -87,13 +101,11 @@ class AioBaseLock(metaclass=CoroBuilder):
         self._threaded_acquire = False
         return out
 
-    @asyncio.coroutine
-    def __aenter__(self):
-        yield from self.coro_acquire()
+    async def __aenter__(self):
+        await self.coro_acquire()
         return None
 
-    @asyncio.coroutine
-    def __aexit__(self, *args, **kwargs):
+    async def __aexit__(self, *args, **kwargs):
         self.release()
 
     def __enter__(self):
@@ -102,14 +114,14 @@ class AioBaseLock(metaclass=CoroBuilder):
     def __exit__(self, *args, **kwargs):
         return self._obj.__exit__(*args, **kwargs)
 
-    def __iter__(self):
-        yield from self.coro_acquire()
+    async def __aiter__(self):
+        await self.coro_acquire()
         return _ContextManager(self)
 
 
 class AioBaseWaiter(metaclass=CoroBuilder):
     pool_workers = 1
-    coroutines = ['wait']
+    coroutines = ["wait"]
 
 
 class AioBarrier(AioBaseWaiter):
@@ -120,7 +132,7 @@ class AioBarrier(AioBaseWaiter):
 class AioCondition(AioBaseLock, AioBaseWaiter):
     delegate = Condition
     pool_workers = 1
-    coroutines = ['wait_for', 'notify', 'notify_all']
+    coroutines = ["wait_for", "notify", "notify_all"]
 
 
 class AioEvent(AioBaseWaiter):
